import react, { useState } from 'react';
import { Map, Marker, ZoomControl } from 'pigeon-maps';
import { useDispatch } from 'react-redux';

import { gpxActions } from '../store/gpx';
import GPXOverlay from './gpx-overlay';
import { registerBackgroundGeolocation } from '../lib/geolocation';

const LiveMap: react.FC = () => {
  const initialCenter: [number, number] = [43.57154, 3.94351];
  const initialZoom: number = 15;
  const [initialized, setInitialized] = useState(false);
  const [center, setCenter] = useState(initialCenter);
  const [position, setPosition] = useState(initialCenter);
  const [zoom, setZoom] = useState(initialZoom);

  const dispatch = useDispatch();

  if (!initialized) {
    dispatch(
      gpxActions.clearGPX({
        trkKey: 'current',
      })
    );
    dispatch(
      gpxActions.appendTrkpt({
        trkKey: 'current',
        trkpt: {
          $: {
            lat: 43.57154,
            lon: 3.94351,
          },
        },
      })
    );
    dispatch(
      gpxActions.appendTrkpt({
        trkKey: 'current',
        trkpt: {
          $: {
            lat: 43.56922,
            lon: 3.94228,
          },
        },
      })
    );
    registerBackgroundGeolocation(dispatch);
    setInitialized(true);
  }

  return (
    <Map
      center={center}
      zoom={zoom}
      onBoundsChanged={({ center, zoom }) => {
        setCenter(center);
        setZoom(zoom);
      }}
      animate={true}
    >
      <GPXOverlay mapState={undefined} latLngToPixel={undefined} />
      <Marker width={20} anchor={position} />
      <ZoomControl />
    </Map>
  );
};

export default LiveMap;
